@@ -15,6 +15,15 @@ diff.ecdf <- ecdf(t.diff)
 res <- lapply(t.pos, FUN=diagnostic_window, window.size=window.size, measured=measured, modelled=modelled,use_qualV=use_qualV, diff.ecdf=diff.ecdf)
 r.diag<-do.call("rbind", res)
 
+if(length(res)!=NROW(r.diag)){
+    print("unexpected length(res)!=NROW(r.diag)")
+    the.names <- colnames(res[[1]])
+    all.elements <- sapply(res, FUN=function(x){all(colnames(x)==the.names)})
+    browser()
+    ele.comp <- sapply(1:length(res), FUN=function(x){bla <- try(all(res[[x]]==r.diag[x,],na.rm=TRUE));if(inherits(bla,"try-error")) print(paste("Not possible for", x));return(bla)})
+}
+
+
 
 #multiplicative correction of integrated flow
 #time series need the same number of NA
@@ -32,6 +41,8 @@ toAppend<-data.frame(matrix(nrow=floor(window.size/step.size),ncol=NCOL(r.diag))
 names(toAppend) <- names(r.diag)
 r.diag<-rbind(toAppend,r.diag)
 
+stopifnot(NROW(r.diag)==NROW(modelled))
+
 return(r.diag)
 
 }
